@@ -73,8 +73,6 @@ class DaskExpr(
     def __call__(self, df: DaskLazyFrame) -> Sequence[dx.Series]:
         return self._call(df)
 
-    def __narwhals_expr__(self) -> None: ...
-
     def __narwhals_namespace__(self) -> DaskNamespace:  # pragma: no cover
         from narwhals._dask.namespace import DaskNamespace
 
@@ -448,7 +446,7 @@ class DaskExpr(
                 if get_dtype_backend(expr.dtype, self._implementation)
                 else value_numpy
             )
-            return expr.mask(mask, fill)
+            return expr.mask(mask, fill)  # pyright: ignore[reportArgumentType]
 
         return self._with_callable(func, "fill_nan")
 
